==> tworice-auth-1.5.0-sources.jar: cn/tworice/auth/interceptor/SQLInjectionInterceptor.java <==
package cn.tworice.auth.interceptor;

import cn.tworice.auth.service.SQLInjectionService;
import cn.tworice.common.vo.RequestResult;
import com.alibaba.fastjson.JSON;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

public class SQLInjectionInterceptor implements HandlerInterceptor {

    @Resource
    private SQLInjectionService sqlInjectionService;

    @Value("${tworice.auth.sqlInjection:true}")
    private Boolean sqlInjection;
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler){
        if(!sqlInjection){
            return true;
        }

        String origin  = request.getHeader(HttpHeaders.ORIGIN);
        if (origin != null) {
            response.setHeader("Access-Control-Allow-Origin", "*");
            response.setHeader("Access-Control-Allow-Methods", "POST, GET, OPTIONS, DELETE, PUT, HEAD");
            response.setHeader("Access-Control-Allow-Headers", "Content-Type, Token, adminID");
            response.setHeader("Access-Control-Max-Age", "3600");
        }
        // 判断请求参数中是否包含SQL注入
        if(sqlInjectionService.isSQLInjection(request)){
            returnJson(response, "您的请求包含SQL注入");
        }

        return true;
    }

    /**
     * 请求被拦截后返回给客户端数据
     * @author 二饭
     * @Email 1786705138@qq.com
     */
    private void returnJson(HttpServletResponse response,String message){
        PrintWriter writer = null;
        response.setCharacterEncoding("UTF-8");
        response.setContentType("text/html; charset=utf-8");
        String jsonString = JSON.toJSONString(RequestResult.error(401,message));
        try {
            writer = response.getWriter();
            writer.print(jsonString);
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (writer != null) {
                writer.close();
            }
        }
    }
}

==> tworice-auth-1.5.2-sources.jar: cn/tworice/auth/interceptor/SQLInjectionInterceptor.java <==
package cn.tworice.auth.interceptor;

import cn.tworice.auth.config.AuthProperties;
import cn.tworice.auth.service.SQLInjectionService;
import cn.tworice.common.framework.mail.core.MailExecutor;
import cn.tworice.common.util.NetworkUtil;
import cn.tworice.common.util.StringUtils;
import cn.tworice.common.vo.RequestResult;
import com.alibaba.fastjson.JSON;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

public class SQLInjectionInterceptor implements HandlerInterceptor {

    @Resource
    private SQLInjectionService sqlInjectionService;

    @Resource
    private AuthProperties authProperties;

    @Resource
    private MailExecutor mailExecutor;

    @Value("${tworice.auth.sqlInjection:true}")
    private Boolean sqlInjection;
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler){
        if(!sqlInjection){
            return true;
        }

        String origin  = request.getHeader(HttpHeaders.ORIGIN);
        if (origin != null) {
            response.setHeader("Access-Control-Allow-Origin", "*");
            response.setHeader("Access-Control-Allow-Methods", "POST, GET, OPTIONS, DELETE, PUT, HEAD");
            response.setHeader("Access-Control-Allow-Headers", "Content-Type, Token, adminID");
            response.setHeader("Access-Control-Max-Age", "3600");
        }
        // 判断请求参数中是否包含SQL注入
        if(sqlInjectionService.isSQLInjection(request)){
            // 发送报警邮件
            if(!StringUtils.isEmpty(authProperties.getMailBlast())){
                String clientIP = NetworkUtil.getClientIP(request);
                mailExecutor.sendMail(authProperties.getMailBlast(), "检测到恶意登录请求", "IP地址：" + clientIP + "，疑似存在SQL注入攻击");
            }
            returnJson(response, "您的请求包含SQL注入");
        }

        return true;
    }

    /**
     * 请求被拦截后返回给客户端数据
     * @author 二饭
     * @Email 1786705138@qq.com
     */
    private void returnJson(HttpServletResponse response,String message){
        PrintWriter writer = null;
        response.setCharacterEncoding("UTF-8");
        response.setContentType("text/html; charset=utf-8");
        String jsonString = JSON.toJSONString(RequestResult.error(401,message));
        try {
            writer = response.getWriter();
            writer.print(jsonString);
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (writer != null) {
                writer.close();
            }
        }
    }
}
